@@ -9,8 +9,10 @@ from multimethod import multidispatch, multimethod
 from unicodedata import normalize
 from collections import OrderedDict
 from enum import Enum
+import snoop
 
 __all__ = [
+    "urange",
     "uDict",
     "iDict",
     "StrCase",
@@ -33,6 +35,90 @@ class ReplaceFor(str, Enum):
 
 ReplaceForType = Literal[ReplaceFor.KEY, ReplaceFor.VALUE]
 
+class urange(object):
+    def __init__(self,
+        *args: int,
+        **kwargs: Any
+    ):
+        """Return an object that produces a sequence of integes
+
+        range(stop) -> range object
+        range(start, stop[, step]) -> range object
+        range(start, stop[, func]) -> range object
+
+        from start (inclusive) to stop (exclusive) by step.
+
+          range(i, j) produces i, i+1, i+2, ..., j-1.
+          range(i, j, k) produces i, i+k, i+2, ..., j-k.
+
+        start defaults to 0, and stop is omitted!
+
+          range(4) produces 0, 1, 2, 3.
+
+        These are exactly the valid indices for a list of 4 elements.
+        When step is given, it specifies the increment (or decrement).
+
+        if set step as callable, pass parameter current value.
+        So, you should define as following function.
+          def step(val: int)->int:
+              # something to do for val
+              return val
+        """
+
+        if len(args) == 1:
+            self._i = 0
+            self._end = args[0]
+            self._step = kwargs.get('step', 0)
+        elif len(args) == 2:
+            self._i = args[0]
+            self._end = args[1]
+            self._step = kwargs.get('step', 0)
+        elif len(args) >= 3:
+            self._i = args[0]
+            self._end = args[1]
+            self._step = args[2]
+        else:
+            self._i = kwargs.get('start', 0)
+            self._end = kwargs.get('end')
+            self._step = kwargs.get('step', 0)
+
+        self.step_callable = callable(self._step)
+        snoop.pp(self.step_callable)
+        if self._i <= self._end:
+            self.ascending = True
+            if self._step == 0:
+                self._step = 1
+            elif not self.step_callable and (self._step < 0):
+                raise ValueError(
+                      'Step must be postitive value for ascending orders.')
+        else:
+            self.ascending = False
+            if self._step == 0:
+                self._step = -1
+            elif not self.step_callable and (self._step > 0):
+                raise ValueError(
+                      'Step must be negative value for descending orders.')
+
+    def __iter__(self):
+        return self
+
+    @snoop
+    def __next__(self):
+        if self.ascending:
+            if self._i >= self._end:
+                raise StopIteration
+        else:
+            if self._i <= self._end:
+                raise StopIteration
+
+        value = self._i
+        if self.step_callable:
+            self._i = self._i + self._step(self._i)
+        else:
+            self._i = self._i + self._step
+        return value
+
+
 class uDict(dict):
     __hash__ = None
 
@@ -445,8 +531,14 @@ def df_compare(
     diffs = len(diff_df)
     return diffs
 
-def split_chunks(
-        iterable: Iterable,
+@multidispatch
+def split_chunks( *args: Any, **kwargs: Any ):
+    """ dispatch function split_chunks """
+    raise TypeError('Invalid Type')
+
+@split_chunks.register
+def _split_chunks_list(
+        data: list,
         chunk_size: int,
         fill_na: bool=True,
         na_value: Optional[Union[int,str,float]]=None
@@ -454,8 +546,8 @@ def split_chunks(
     """Return split into even chunk_size elements for iterable
     Parameters
     ----------
-    iterable: list
-        to split list
+    data: list
+        to split itrtable ojects. i.e.: list, tuple, dict, set.
     chunk_size: int
         the size of chunk list.
     fill_na: bool
@@ -469,13 +561,124 @@ def split_chunks(
         splited list
     """
 
-    for x in range(0, len(iterable), chunk_size):
-        every_chunk = iterable[x: chunk_size+x]
+    iterable = iter(data)
+    for x in range(0, len(data), chunk_size):
+        chunk_data = list()
+        for _ in urange(chunk_size):
+            try:
+                chunk_data.append(next(iterable))
+            except StopIteration:
+                break
 
-        if fill_na and len(every_chunk) < chunk_size:
-            every_chunk += [ na_value
-                             for y in range(chunk_size-len(every_chunk))]
-        yield every_chunk
+        if fill_na and (len(chunk_data) < chunk_size):
+            chunk_data += [ na_value
+                            for y in urange(chunk_size-len(chunk_data))]
+        yield chunk_data
+
+@split_chunks.register
+def _split_chunks_tuple(
+        data: tuple,
+        chunk_size: int,
+        fill_na: bool=True,
+        na_value: Optional[Union[int,str,float]]=None
+    ) ->list:
+    """Return split into even chunk_size elements for iterable
+    Parameters
+    ----------
+    data: tuple
+        to split itrtable ojects. i.e.: list, tuple, dict, set.
+    chunk_size: int
+        the size of chunk list.
+    fill_na: bool
+        subset of a list does not fit in the size of the defined chunk,
+        fillers need to be inserted in the place of the empty element holders.
+        fillers is able to set `na_value`.
+    na_value: int, str, default is `None`.
+
+    Returns
+    -------
+        splited list
+    """
+
+    iterable = iter(data)
+    for x in range(0, len(data), chunk_size):
+        chunk_data = list()
+        for _ in urange(chunk_size):
+            try:
+                chunk_data.append(next(iterable))
+            except StopIteration:
+                break
+
+        if fill_na and (len(chunk_data) < chunk_size):
+            chunk_data += [ na_value
+                            for y in range(chunk_size-len(chunk_data))]
+        yield tuple(chunk_data)
+
+
+@split_chunks.register
+def _split_chunks_dict(
+        data: dict,
+        chunk_size: int,
+        *args: Any,
+        **kwargs: Any,
+    ) ->list:
+    """Return split into even chunk_size elements for iterable
+    Parameters
+    ----------
+    data: dict
+        to split dict ojects.
+    chunk_size: int
+        the size of chunk list.
+    na_value: int, str, default is `None`.
+
+    Returns
+    -------
+        splited list
+    """
+
+    iterable = iter(data)
+    for x in range(0, len(data), chunk_size):
+        chunk_data = dict()
+        for _ in urange(chunk_size):
+            try:
+                key = next(iterable)
+                chunk_data[key] = data[key]
+            except StopIteration:
+                break
+
+        yield chunk_data
+
+@split_chunks.register
+def _split_chunks_str(
+        data: str,
+        chunk_size: int,
+        *args: Any,
+        **kwargs: Any,
+    ) ->list:
+    """Return split into even chunk_size elements for iterable
+    Parameters
+    ----------
+    data: str
+        to split dict ojects.
+    chunk_size: int
+        the size of chunk list.
+    na_value: int, str, default is `None`.
+
+    Returns
+    -------
+        splited str list
+    """
+
+    iterable = iter(data)
+    for x in range(0, len(data), chunk_size):
+        chunk_data = ""
+        for _ in urange(chunk_size):
+            try:
+                 chunk_data += next(iterable).replace('\n', '')
+            except StopIteration:
+                break
+
+        yield chunk_data
 
 
 class StrCase(object):
